/*
 * defaultiostrategy.cpp
 *
 * @author Pietro Spinella (scrockman[at]gmail[dot]com)
 * @license GPLv3
 */

#include <QInputDialog>
#include <QMessageBox>

#include "defaultiostrategy.h"

using namespace kms;

kms::DefaultIOStrategy::DefaultIOStrategy() {
	// Creates the captcha manager
	_captchaManager = new CaptchaManager;
}

kms::DefaultIOStrategy::~DefaultIOStrategy() {
	// Deletes the captcha manager
	delete _captchaManager;
}

QList< QPair<QString, QString> > kms::DefaultIOStrategy::getInputs(const QList< QHash<QString, QString> > &inputs, bool *ok) {

	QList< QPair<QString, QString> > values;

	for(int i = 0; i < inputs.size(); i++) {
		QHash<QString, QString> hash = inputs.at(i);
		if(hash["type"] != "constant" && hash["type"] != "variable" && hash["type"] != "contextual") {
			continue;
		}
		if(hash["content"] != "string" && hash["content"] != "password" && hash["content"] != "text" && hash["content"] != "collection" && hash["content"] != "captcha") {
			continue;
		}
		if(hash["content"] == "string" || hash["content"] == "password" || hash["content"] == "text") {
			QLineEdit::EchoMode mode;
			if(hash["content"] == "password") {
				mode = QLineEdit::Password;
			} else {
				mode = QLineEdit::Normal;
			}
			bool okFlag;
			QString value = QInputDialog::getText(0, "Input", hash["name"], mode, hash["defaultValue"], &okFlag);
			QPair<QString, QString> pair;
			pair.first = hash["id"];
			if(ok != 0) {
				*ok = okFlag;
			}
			if(okFlag == true) {
				pair.second = value;
			} else {
				pair.second = "";	// TODO: handle the cancel button
				return values;
			}
			values.append(pair);
			continue;
		}
		if(hash["content"] == "collection") {
			// TODO
			continue;
		}
		if(hash["content"] == "captcha") {
			// TODO
			continue;
		}
	}

	return values;

}

QPair<QString, QString> kms::DefaultIOStrategy::getInput(const QHash<QString, QString> &input, bool *ok) {

	// Creates a temporaneous list
	QList< QHash<QString, QString> > list;
	list.append(input);

	// Gets the inputs
	bool okFlag;
	QList< QPair<QString, QString> > inputs = getInputs(list, &okFlag);
	if(ok != 0) {
		*ok = okFlag;
	}

	// return the result
	return inputs.size() == 1 ? inputs.at(0) : QPair<QString, QString>();

}

QString kms::DefaultIOStrategy::getCaptchaInput(const QHash<QString, QString> &input, const QByteArray &data, bool *ok) {

	_captchaManager->setCaptcha(data);
	_captchaManager->setVisible(true);

	bool okFlag;
	QString result = QInputDialog::getText(0, "Input", input["name"], QLineEdit::Normal, "", &okFlag);
	if(ok != 0) {
		*ok = okFlag;
	}
	_captchaManager->setVisible(false);

	delete _captchaManager;

	return result;

}

void kms::DefaultIOStrategy::showMessage(const QString &message) {
	// Shows an output message
	QMessageBox::information(0, "Output", message);
}
