/*
 * enhancedqhttp.cpp
 *
 * @author Pietro Spinella (scrockman[at]gmail[dot]com)
 * @license GPLv3
 */

#include <QList>
#include <QPair>
#include <QString>
#include <QUrl>

#include "enhancedqhttp.h"

using namespace kms;

kms::EnhancedQHttp::EnhancedQHttp() {

	// Creates the cookie manager
	_cookieManager = new CookieManager;

	// Connects the slots
	connect(this, SIGNAL(responseHeaderReceived(const QHttpResponseHeader &)), this, SLOT(manageResponse(const QHttpResponseHeader &)));
	connect(this, SIGNAL(done(bool)), this, SLOT(manageDone(bool)));

	// Sets this flag
	requestPerformedFlag = -1;

}

kms::EnhancedQHttp::~EnhancedQHttp() {

	// Deletes the cookie manager
	delete _cookieManager;

	// Disconnects the slots
	disconnect(this, 0, 0, 0);

}

CookieManager *kms::EnhancedQHttp::getCookieManager() {

	// Returns the cookie manager
	return _cookieManager;

}

void kms::EnhancedQHttp::manageResponse(const QHttpResponseHeader &responseHeader) {

	int statusCode = responseHeader.statusCode();

			// Stores the cookies into the cookie manager
			QList< QPair<QString, QString> > values = responseHeader.values();
			for(QList< QPair<QString ,QString> >::iterator i = values.begin(); i != values.end(); i++) {
				if((*i).first.compare("set-cookie", Qt::CaseInsensitive) == 0) {
					_cookieManager->setCookie((*i).second);
				}
			}

	switch(statusCode) {
		// Continue
		case 100: {
			qDebug("[kms::EnhancedQHttp] Response header received with status code 200 (Continue)");
			break;
		}
		// Ok
		case 200: {
			qDebug("[kms::EnhancedQHttp] Response header received with status code 200 (Ok)");
			break;
		}
		// Redirect
		case 302: {
			qDebug("[kms::EnhancedQHttp] Response header received with status code 302 (Redirect)");
			// Does the redirect
			QString location = responseHeader.value("Location");
			QString host = location.left(location.indexOf("/", 7)).remove(0,7);		// TODO modify
			location.remove(0,location.indexOf("/", 7));
			QHttpRequestHeader header("GET", location);	// TODO modify
			header.setValue("Host", host);
			setHost(host);
			_cookieManager->attachCookies(&header);
			request(header);
			break;
		}
		// Not Found
		case 404: {
			qDebug("[kms::EnhancedQHttp] Response header received with status code 404 (Not Found)");
			break;
		}
		// Internal Server Error
		case 500: {
			qDebug("[kms::EnhancedQHttp] Response header received with status code 500 (Internal Server Error)");
			break;
		}
		// Unknown
		default: {
			qDebug("[kms::EnhancedQHttp] Response header received with status code ??? (Unknown)");
			break;
		}
	}

	// Signals that the request has been performed
	if((statusCode >= 200 && statusCode <= 299) || (statusCode >= 400 && statusCode <= 599)) {
		qDebug(" ");
		requestPerformedFlag = statusCode;
//		emit requestPerformed(statusCode);
	}

}

void kms::EnhancedQHttp::manageDone(bool /*error*/) {

	if(requestPerformedFlag != -1) {
		requestPerformedFlag = -1;
		QByteArray data = readAll();
		emit requestPerformed(data);
	}

}
