/*
 * service.h
 *
 * $author Pietro Spinella (pietro.spinella@gmail@com)
 * $license GPLv3
 */

#ifndef KMS_SERVICE_H
#define KMS_SERVICE_H

#include <QString>

#include "texts.h"
#include "inputs.h"
#include "outputs.h"
#include "actions.h"
#include "sequences.h"

namespace kms {

	class Service {

		public:
			Service();
			~Service();

			const QString &getId() const;
			const QString &getName() const;
			const QString &getIcon() const;
			const QString &getDescription() const;
			const QString &getVersion() const;
			const QString &getAuthor() const;
			const QString &getEnabled() const;

			const Texts *getTexts() const;
			const Inputs *getInputs() const;
			const Outputs *getOutputs() const;
			const Actions *getActions() const;
			const Sequences *getSequences() const;

			void setId(const QString &id);
			void setName(const QString &name);
			void setIcon(const QString &icon);
			void setDescription(const QString &description);
			void setVersion(const QString &version);
			void setAuthor(const QString &author);
			void setEnabled(const QString &enabled);

			void setTexts(const Texts *texts);
			void setInputs(const Inputs *inputs);
			void setOutputs(const Outputs *outputs);
			void setActions(const Actions *actions);
			void setSequences(const Sequences *sequences);

		private:
			QString _id;
			QString _name;
			QString _icon;
			QString _description;
			QString _version;
			QString _author;
			QString _enabled;

			Texts *_texts;
			Inputs *_inputs;
			Outputs *_outputs;
			Actions *_actions;
			Sequences *_sequences;

	};

};

#endif
