/*
 * accountitemdelegate.cpp
 *
 * @author Pietro Spinella (scrockman[at]gmail[dot]com)
 * @license GPLv3
 */

#include <QLineEdit>
#include <QComboBox>

#include "accountitemdelegate.h"
#include "providers/provider.h"

using namespace kms;

kms::AccountItemDelegate::AccountItemDelegate(QObject *parent) : QItemDelegate(parent) {

	_parent = (MainWindow *) parent;

}

QWidget *kms::AccountItemDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &/*option*/, const QModelIndex &index) const {

	// Get the right column index
	int column = index.column();

	// Name
	if(column == 0) {
		return new QLineEdit(parent);
	}

	// Type
	if(column == 1) {
		QComboBox *comboBox = new QComboBox(parent);
		// Set the provider list into the combo box
		for(QList<Provider *>::iterator i = _parent->_providerList.begin(); i != _parent->_providerList.end(); i++) {
			comboBox->addItem(QIcon(QString::fromUtf8(":/images/images/account.png")), (*i)->getName());
		}
		return comboBox;
	}

	// Username
	if(column == 2) {
		return new QLineEdit(parent);
	}

	// Password
	if(column == 3) {
		QLineEdit *lineEdit = new QLineEdit(parent);
//		lineEdit->setEchoMode(QLineEdit::Password);
		return lineEdit;
	}

	return new QWidget;

}

void kms::AccountItemDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const {

	// Get the right column index
	int column = index.column();

	// Name
	if(column == 0) {
		QLineEdit *lineEdit = qobject_cast<QLineEdit *>(editor);
		QString text = index.model()->data(index, Qt::DisplayRole).toString();
		lineEdit->setText(text);
		return;
	}

	// Type
	if(column == 1) {
		QComboBox *comboBox = qobject_cast<QComboBox *>(editor);
		int i = comboBox->findText(index.model()->data(index).toString(), Qt::MatchExactly);
		comboBox->setCurrentIndex(i);
		return;
	}

	// Username
	if(column == 2) {
		QLineEdit *lineEdit = qobject_cast<QLineEdit *>(editor);
		QString text = index.model()->data(index, Qt::DisplayRole).toString();
		lineEdit->setText(text);
		return;
	}

	// Password
	if(column == 3) {
		QLineEdit *lineEdit = qobject_cast<QLineEdit *>(editor);
		QString text = index.model()->data(index, Qt::DisplayRole).toString();
//		lineEdit->setEchoMode(QLineEdit::Password);
		lineEdit->setText(text);
		return;
	}

}

void kms::AccountItemDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const {

	// Get the right column index
	int column = index.column();

	// Name
	if(column == 0) {
		QLineEdit *lineEdit = qobject_cast<QLineEdit *>(editor);
		model->setData(index, lineEdit->text());
		return;
	}

	// Type
	if(column == 1) {
		QComboBox *comboBox = qobject_cast<QComboBox *>(editor);
		model->setData(index, comboBox->currentText());
	}

	// Username
	if(column == 2) {
		QLineEdit *lineEdit = qobject_cast<QLineEdit *>(editor);
		model->setData(index, lineEdit->text());
		return;
	}

	// Password
	if(column == 3) {
		QLineEdit *lineEdit = qobject_cast<QLineEdit *>(editor);
//		lineEdit->setEchoMode(QLineEdit::Password);
		model->setData(index, lineEdit->text());
		return;
	}

}
