/*
 * mainwindow.h
 *
 * @author Pietro Spinella (scrockman[at]gmail[dot]com)
 * @license GPLv3
 */

#ifndef SCROCKSMS_MAIN_WINDOW_H
#define SCROCKSMS_MAIN_WINDOW_H

#include <QHttpRequestHeader>
#include <QItemDelegate>
#include <QLineEdit>
#include <QMainWindow>
#include <QMenu>
#include <QString>
#include <QSystemTrayIcon>
#include <QTextEdit>

#include "ui_kms.h"

#include "sources/support/textpacker/textpacker.h"
#include "sources/support/textpacker/simplealgorithm.h"
#include "sources/support/textpacker/elegantalgorithm.h"
#include "sources/support/textpacker/smartalgorithm.h"
#include "sources/support/textpacker/compactalgorithm.h"
#include "sources/support/textpacker/crypticalgorithm.h"
#include "sources/support/textpacker/crazyalgorithm.h"
#include "sources/support/textpacker/nastyalgorithm.h"

#include "providers/provider.h"
#include "account.h"
#include "cookiemanager.h"
#include "accountmanager.h"

#include "sources/core/captchamanager/captchamanager.h"

#include "scheduler.h"
	#include <QCloseEvent>
using namespace kms;

namespace kms {

	class Scheduler;
class Provider;
class Account;

	class MainWindow : public QMainWindow {

		Q_OBJECT

		public:

			MainWindow();
			~MainWindow();

			void loadSettings();
			void saveSettings();

			void loadIndexBook();
			void saveIndexBook();

			void loadModels();
			void saveModels();

			CaptchaManager *getCaptchaManager();

//TODO			QTextEdit *getDebugManager();
			QTextEdit *debugTextEdit;

		protected:

		private slots:

			// Tray icon
			void slot_saveAllAndQuit();
			void slot_iconActivated(QSystemTrayIcon::ActivationReason reason);
			void slot_trayIconActionPerformed();

			// Credits tab
			void slot_webSiteQPushButtonClicked();
			void slot_forumQPushButtonClicked();

			// Message tab
			void slot_senderQLineEditTextChanged(QString text);
			void slot_recipientQLineEditTextChanged(QString text);
			void slot_textQTextEditChanged();
			void slot_sendQPushButtonClicked();
			void slot_packingQComboBoxCurrentIndexChanged(int index);

			// Indexbook tab
			void slot_useAsReceiverQPushButtonClicked();
			void slot_newQPushButtonClicked();
			void slot_removeQPushButtonClicked();
			void slot_indexBookTableWidgetCellChanged(int row, int column);

			// Models tab
			void slot_useAsTextQPushButtonClicked();
			void slot_newModelQPushButtonClicked();
			void slot_removeModelQPushButtonClicked();
			void slot_modelsQListWidgetItemDoubleClicked(QListWidgetItem *item);
			void slot_modelsQListWidgetItemSelectionChanged();

			void slot_accountQComboBoxCurrentIndexChanged(int index);
			void slot_showAccountInfoStateChanged(int status);

		// Credits management


		// Status management

			// Updates the status bar (remaining characters, ...)
			void _updateStatus();

		public:

		// Providers and accounts management

			// Stores the provider list
			QList<Provider *> _providerList;

			// Stores the account list
			QList<Account *> _accountList;

			CaptchaManager *_captchaManager;
		private:

			AccountManager *_accountManager;

		// Message scheduler

			Scheduler *_scheduler;

		// User interface management

			// Stores the user interface
			Ui::MainWindow _ui;

		// Tray icon management

			// Stores the system tray (and related objects)
			QSystemTrayIcon *_trayIcon;
			QAction *_quitAction;
			QMenu *_trayIconMenu;

		// Text packing management

			// Stores the dictionary used by the packing algorithms
			QList<QPair<QString, QString> > _dictionary;

			// Store the text packer and the packing algorithms
			TextPacker _textPacker;
			SimpleAlgorithm _simpleAlgorithm;
			ElegantAlgorithm _elegantAlgorithm;
			SmartAlgorithm _smartAlgorithm;
			CompactAlgorithm _compactAlgorithm;
			CrypticAlgorithm _crypticAlgorithm;
			CrazyAlgorithm _crazyAlgorithm;
			NastyAlgorithm _nastyAlgorithm;

			// Stores some variables for the packing feature
			int _lastPackingIndex;
			QString _originalText;

		// Internals variables

			// Store the address of the QLineEdit of the recipient (temp.)
			QLineEdit *_recipientQLineEdit;
			// Store the current account
			Account *_currentAccount;

		// Da sistemare

			QItemDelegate *_accountItemDelegate;

	};

};

#endif
