/*
 * provider.cpp
 *
 * @author Pietro Spinella (scrockman[at]gmail[dot]com)
 * @license GPLv3
 */

#include "providers/provider.h"

using namespace kms;

kms::Provider::Provider() : _acceptsSender(false),
			_acceptsRecipient(false),
			_acceptsSubject(false),
			_acceptsText(false),
				_maxSenderLenght(-1),
				_maxRecipientLenght(-1),
				_maxSubjectLenght(-1),
				_maxTextLenght(-1),
					_senderRegExp(QRegExp(".*")),
					_recipientRegExp(QRegExp(".*")),
					_subjectRegExp(QRegExp(".*")),
					_textRegExp(QRegExp(".*")) {
	// Does nothing...
}

kms::Provider::~Provider() {
	// Does nothing...
}

QString kms::Provider::getName() const {
	return _name;
}

bool kms::Provider::acceptsSender() const {
	return _acceptsSender;
}

bool kms::Provider::acceptsRecipient() const {
	return _acceptsRecipient;
}

bool kms::Provider::acceptsSubject() const {
	return _acceptsSubject;
}

bool kms::Provider::acceptsText() const {
	return _acceptsText;
}

int kms::Provider::getMaxSenderLenght() const {
	return _maxSenderLenght;
}

int kms::Provider::getMaxRecipientLenght() const {
	return _maxRecipientLenght;
}

int kms::Provider::getMaxSubjectLenght() const {
	return _maxSubjectLenght;
}

int kms::Provider::getMaxTextLenght() const {
	return _maxTextLenght;
}

QRegExp kms::Provider::getSenderRegExp() const {
	return _senderRegExp;
}

QRegExp kms::Provider::getRecipientRegExp() const {
	return _recipientRegExp;
}

QRegExp kms::Provider::getSubjectRegExp() const {
	return _subjectRegExp;
}

QRegExp kms::Provider::getTextRegExp() const {
	return _textRegExp;
}

void kms::Provider::setName(const QString &name) {
	_name = name;
}

void kms::Provider::setAcceptsSender(bool value) {
	_acceptsSender = value;
}

void kms::Provider::setAcceptsRecipient(bool value) {
	_acceptsRecipient = value;
}

void kms::Provider::setAcceptsSubject(bool value) {
	_acceptsSubject = value;
}

void kms::Provider::setAcceptsText(bool value) {
	_acceptsText = value;
}

void kms::Provider::setMaxSenderLenght(const int maxSenderLenght) {
	_maxSenderLenght = maxSenderLenght;
}

void kms::Provider::setMaxRecipientLenght(const int maxRecipientLenght) {
	_maxRecipientLenght = maxRecipientLenght;
}

void kms::Provider::setMaxSubjectLenght(const int maxSubjectLenght) {
	_maxSubjectLenght = maxSubjectLenght;
}

void kms::Provider::setMaxTextLenght(const int maxTextLenght) {
	_maxTextLenght = maxTextLenght;
}

void kms::Provider::setSenderRegExp(const QRegExp &senderRegExp) {
	_senderRegExp = senderRegExp;
}

void kms::Provider::setRecipientRegExp(const QRegExp &recipientRegExp) {
	_recipientRegExp = recipientRegExp;
}

void kms::Provider::setSubjectRegExp(const QRegExp &subjectRegExp) {
	_subjectRegExp = subjectRegExp;
}

void kms::Provider::setTextRegExp(const QRegExp &textRegExp) {
	_textRegExp = textRegExp;
}

QString kms::Provider::toQString() {
	return QString("[name=" + _name + "]");
}
