/*
 * provider.h
 *
 * @author Pietro Spinella (scrockman[at]gmail[dot]com)
 * @license GPLv3
 */

#ifndef KMS_PROVIDER_H
#define KMS_PROVIDER_H

#include <QRegExp>
#include <QString>

#include "providers/servant.h"
#include "mainwindow.h"

namespace kms {

	class Servant;

	class Provider {

		public:
			Provider();
			virtual ~Provider();

			QString getName() const;

			bool acceptsSender() const;
			bool acceptsRecipient() const;
			bool acceptsSubject() const;
			bool acceptsText() const;

			int getMaxSenderLenght() const;
			int getMaxRecipientLenght() const;
			int getMaxSubjectLenght() const;
			int getMaxTextLenght() const;

			QRegExp getSenderRegExp() const;
			QRegExp getRecipientRegExp() const;
			QRegExp getSubjectRegExp() const;
			QRegExp getTextRegExp() const;

			virtual Servant *createServant(MainWindow *mainWindow) = 0;

			QString toQString();

		protected:
			void setName(const QString &name);

			void setAcceptsSender(bool value);
			void setAcceptsRecipient(bool value);
			void setAcceptsSubject(bool value);
			void setAcceptsText(bool value);

			void setMaxSenderLenght(const int maxSenderLenght);
			void setMaxRecipientLenght(const int maxRecipientLenght);
			void setMaxSubjectLenght(const int maxSubjectLenght);
			void setMaxTextLenght(const int maxTextLenght);

			void setSenderRegExp(const QRegExp &senderRegExp);
			void setRecipientRegExp(const QRegExp &recipientRegExp);
			void setSubjectRegExp(const QRegExp &subjectRegExp);
			void setTextRegExp(const QRegExp &textRegExp);

		private:
			QString _name;

			bool _acceptsSender;
			bool _acceptsRecipient;
			bool _acceptsSubject;
			bool _acceptsText;

			int _maxSenderLenght;
			int _maxRecipientLenght;
			int _maxSubjectLenght;
			int _maxTextLenght;

			QRegExp _senderRegExp;
			QRegExp _recipientRegExp;
			QRegExp _subjectRegExp;
			QRegExp _textRegExp;

	};

};

#endif
