/*
 * telephonenumber.cpp
 *
 * $author Pietro Spinella (scrockman@gmail.com)
 */

#include "telephonenumber.h"

using namespace kms;

kms::TelephoneNumber::TelephoneNumber(QWidget * parent, Qt::WindowFlags f) : QWidget(parent, f), currentCountryIndex(0) {

	// Creates international prefixes
	countryList = new QList<QPair<QString,QString> >;
	QPair<QString,QString> country;
	country.first = ""; country.second = ""; countryList->append(country);
	country.first = "Italy"; country.second = "+39"; countryList->append(country);
	country.first = "Bahamas"; country.second = "+1242"; countryList->append(country);

	// Creates the internal objects
	internationalPrefixQLabel = new QLabel();
	telephoneNumberQLineEdit = new QLineEdit();
	informationsQLabel = new QLabel();

	// Sets the properties of the QLabels
	QPalette palette = internationalPrefixQLabel->palette();
	palette.setColor(QPalette::WindowText,QColor(0,85,0));
	internationalPrefixQLabel->setPalette(palette);
	palette = informationsQLabel->palette();
	palette.setColor(QPalette::WindowText,QColor(0,85,0));
	informationsQLabel->setPalette(palette);
	QFont font;
	font.setBold(true);
	internationalPrefixQLabel->setFont(font);
	informationsQLabel->setFont(font);
	internationalPrefixQLabel->setVisible(false);
	informationsQLabel->setVisible(false);

	// Creates and sets the layout
	layout = new QHBoxLayout;
	layout->addWidget(internationalPrefixQLabel);
	layout->addWidget(telephoneNumberQLineEdit);
	layout->addWidget(informationsQLabel);
	layout->setMargin(0);
	setLayout(layout);

	// Creates and sets the completer
	completer = new QCompleter;
	completer->setCaseSensitivity(Qt::CaseInsensitive);
	telephoneNumberQLineEdit->setCompleter(completer);

	// Connects the signals with the slots
	connect(telephoneNumberQLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slot_telephoneNumberQLineEditTextChanged(QString)));

}

kms::TelephoneNumber::~TelephoneNumber() {

	disconnect(telephoneNumberQLineEdit, SIGNAL(textChanged(QString)), 0, 0);

	delete completer;

	delete layout;
	delete informationsQLabel;
	delete telephoneNumberQLineEdit;
	delete internationalPrefixQLabel;

	delete countryList;

}

QLabel *kms::TelephoneNumber::getInternationalPrefixQLabel() {

	return internationalPrefixQLabel;

}

QLineEdit *kms::TelephoneNumber::getTelephoneNumberQLineEdit() {

	return telephoneNumberQLineEdit;

}

QLabel *kms::TelephoneNumber::getInformationsQLabel() {

	return informationsQLabel;

}

QAbstractItemModel *kms::TelephoneNumber::getModel() {

	return completer->model();

}

void kms::TelephoneNumber::setModel(QAbstractItemModel *model) {

	completer->setModel(model);

	return;

}

QPair<QString,QString> kms::TelephoneNumber::getCountry() {

	return countryList->at(currentCountryIndex);

}

void kms::TelephoneNumber::setCountry(TelephoneNumber::Country country) {

	switch(country) {
		case TelephoneNumber::Italy:
			currentCountryIndex = 1;
			break;
		case TelephoneNumber::Bahamas:
			currentCountryIndex = 2;
			break;
		default:
			currentCountryIndex = 0;
			break;
	}

}
/*
QString kms::TelephoneNumber::getCompleteNumber() const {

	QString s = telephoneNumberQLineEdit->text();
	if(s.startsWith("+"))

}
*/
void kms::TelephoneNumber::slot_telephoneNumberQLineEditTextChanged(QString text) {

	// TMP
	return;

	// Gets the palette that will be changed
	QPalette palette = telephoneNumberQLineEdit->palette();

	// IS TEXT EMPTY ?
	if(text.size()==0) {
		internationalPrefixQLabel->setVisible(false);
		palette.setColor(QPalette::Base,QColor(255,255,255));
		informationsQLabel->setVisible(false);
		emit statusChanged(TelephoneNumber::Empty);
	} else {
		// IS TEXT A NUMBER FORMAT ?
		if(QRegExp("(\\+|\\d).*").exactMatch(text)==true) {
			// IS TEXT AN ERRORED NUMBER FORMAT ?
			if(QRegExp("(\\+0.*)|(.+\\D.*)").exactMatch(text)==true) {
				palette.setColor(QPalette::Base,QColor(255,0,0));
				palette.setColor(QPalette::WindowText,QColor(255,255,255));
				emit statusChanged(TelephoneNumber::Error);
			} else {
				palette.setColor(QPalette::Base,QColor(255,255,255));
				palette.setColor(QPalette::WindowText,QColor(0,0,0));
				completer->setCompletionMode(QCompleter::InlineCompletion);
				// WHAT INTERNATIONAL PREFIX ?
				if(QRegExp("\\d.*").exactMatch(text)==true) {
					if(internationalPrefixQLabel->isVisible()==false) {
						internationalPrefixQLabel->setText(getCountry().second);
						internationalPrefixQLabel->setVisible(true);
					}
				}
				bool flag = 0;
					for(int i = 0; i<completer->model()->rowCount(); i++) {
						if(QString::compare(completer->model()->data(completer->model()->index(i, 1)).toString(),text,Qt::CaseInsensitive)==0) {
							informationsQLabel->setText(completer->model()->data(completer->model()->index(i, 0)).toString());
							informationsQLabel->setVisible(true);
							flag = 1;
							break;
						}
						if(completer->model()->data(completer->model()->index(i, 1)).toString().startsWith(text,Qt::CaseInsensitive)==true) {
							flag = 2;
							break;
						}
					}
					if(flag != 1) {
						informationsQLabel->setVisible(false);
					}
					if(flag == 1) {
						palette.setColor(QPalette::Base,QColor(0,255,0));
						emit statusChanged(TelephoneNumber::Ok);
					} else if(flag == 2) {
						palette.setColor(QPalette::Base,QColor(255,255,255));
						emit statusChanged(TelephoneNumber::Empty);
					} else {
	//???					palette.setColor(QPalette::Base,QColor(255,0,0));
	//???					emit statusChanged(TelephoneNumber::Error);
					}
			}

		} else {
			// IS TEXT A NON NUMBER FORMAT!
			completer->setCompletionMode(QCompleter::PopupCompletion);
			internationalPrefixQLabel->setVisible(false);
			palette.setColor(QPalette::Base,QColor(255,255,255));
			informationsQLabel->setVisible(false);
			int flag = 0;
				for(int i = 0; i<completer->model()->rowCount(); i++) {
					if(QString::compare(completer->model()->data(completer->model()->index(i, 0)).toString(),text,Qt::CaseInsensitive)==0) {
						informationsQLabel->setText(completer->model()->data(completer->model()->index(i, 1)).toString());
						informationsQLabel->setVisible(true);
						flag = 1;
						break;
					}
					if(completer->model()->data(completer->model()->index(i, 0)).toString().startsWith(text,Qt::CaseInsensitive)==true) {
						flag = 2;
						break;
					}
				}
				if(flag == 1) {
					palette.setColor(QPalette::Base,QColor(0,255,0));
//?					palette.setColor(QPalette::WindowText,QColor(0,0,0));
					emit statusChanged(TelephoneNumber::Ok);
				} else if(flag == 2) {
					palette.setColor(QPalette::Base,QColor(255,255,255));
//?					palette.setColor(QPalette::WindowText,QColor(0,0,0));
					emit statusChanged(TelephoneNumber::Empty);
				} else {
					palette.setColor(QPalette::Base,QColor(255,0,0));
//?					palette.setColor(QPalette::WindowText,QColor(255,255,255));
					emit statusChanged(TelephoneNumber::Error);
				}
		}
	}

	telephoneNumberQLineEdit->setPalette(palette);
	return;

//	QString currentCompletion = completer->currentCompletion();
//	setWindowTitle(currentCompletion);
//	if(currentCompletion==text) {
		int i = 0;
		for(; i<completer->model()->rowCount(); i++) {
			if(QString::compare(completer->model()->data(completer->model()->index(i, 0)).toString(),text,Qt::CaseInsensitive)==0) {
				informationsQLabel->setVisible(true);
				informationsQLabel->setText(completer->model()->data(completer->model()->index(i, 1)).toString());
				break;
			}
			if(QString::compare(completer->model()->data(completer->model()->index(i, 1)).toString(),text,Qt::CaseInsensitive)==0) {
				informationsQLabel->setVisible(true);
				informationsQLabel->setText(completer->model()->data(completer->model()->index(i, 0)).toString());
				break;
			}
		}
		if(i == completer->model()->rowCount()) {
			informationsQLabel->setVisible(false);
			informationsQLabel->setText("");
		}
//	} else {
//		informationsQLabel->setVisible(false);
//	}

	// STARTS WITH A NUMBER ?
	if(QRegExp("\\d.*").exactMatch(text)==true) {
		internationalPrefixQLabel->setText("+39");
		internationalPrefixQLabel->setVisible(true);
		// IS GREEN ? (IS NUMBER IN INDEXBOOK ?)
QString sss = "**********";	// Il mio numero di telefono!
		if(text==sss) {
			informationsQLabel->setText("Pietro");
			informationsQLabel->setVisible(true);
			palette.setColor(QPalette::Base,QColor(0,255,0));
		} else
		// IS YELLOW ?
		if(QRegExp("\\d*").exactMatch(text)==true) {
//			informationsQLabel->setVisible(false);
			palette.setColor(QPalette::Base,QColor(255,255,0));
		} else {
			// IS RED!
//			informationsQLabel->setVisible(false);
			palette.setColor(QPalette::Base,QColor(255,0,0));
		}
	// IS STARTS WITH A NOT NUMBER
	} else {
		// IS WHITE ?
		if(text.size()==0) {
//			informationsQLabel->setVisible(false);
			internationalPrefixQLabel->setVisible(false);
			palette.setColor(QPalette::Base,QColor(255,255,255));
		} else
		// IS GREEN ? (PER ESSERE VERDE DEVE ESSERE IN RUBRICA)
		if(QRegExp("(\\+|00)[1-9]\\d{11}").exactMatch(text)==true) {
			informationsQLabel->setText("Pietro");
			informationsQLabel->setVisible(true);
			palette.setColor(QPalette::Base,QColor(0,255,0));
		} else
		// IS YELLOW ?
		if(QRegExp("\\+|0|00|(\\+[1-9])|(00[1-9])|(\\+[1-9]\\d*)|(00[1-9]\\d*)").exactMatch(text)==true) {
//			informationsQLabel->setVisible(false);
			palette.setColor(QPalette::Base,QColor(255,255,0));
		} else {
			// IS RED!
//			informationsQLabel->setVisible(false);
			palette.setColor(QPalette::Base,QColor(255,0,0));
		}
	}

	// Sets the new palette
	telephoneNumberQLineEdit->setPalette(palette);

}
