/*
 * telephonenumber.h
 *
 * @author Pietro Spinella (scrockman[at]gmail.com)
 */

#ifndef KMS_TELEPHONE_NUMBER_H
#define KMS_TELEPHONE_NUMBER_H

#include <QAbstractItemModel>
#include <QCompleter>
#include <QHBoxLayout>
#include <QLabel>
#include <QLineEdit>
#include <QWidget>

namespace kms {

	class TelephoneNumber : public QWidget {

		Q_OBJECT

		public:

			enum Country {
				None = 0,	// none
				Italy = 1,	// +39
				Bahamas = 2	// +1242
			};

			enum Status {
				Empty = 0,	// empty
				Ok = 1,		// the receiver exists
				Writing = 2,	// the receiver is being writing
				Error = 3	// the receiver doesn't exists
			};

			TelephoneNumber(QWidget *parent = 0, Qt::WindowFlags f = 0);
			~TelephoneNumber();

			QLabel *getInternationalPrefixQLabel();
			QLineEdit *getTelephoneNumberQLineEdit();
			QLabel *getInformationsQLabel();
			QAbstractItemModel *getModel();
			void setModel(QAbstractItemModel *model);

			QPair<QString,QString> getCountry();
			void setCountry(TelephoneNumber::Country country);

			// Tmp
//			QString getCompleteNumber() const;

		signals:
			void statusChanged(int status);

		private:
			QLabel *internationalPrefixQLabel;
			QLineEdit *telephoneNumberQLineEdit;
			QLabel *informationsQLabel;
			QHBoxLayout *layout;
			QCompleter *completer;

			QList<QPair<QString,QString> > *countryList;
			int currentCountryIndex;

		private slots:
			void slot_telephoneNumberQLineEditTextChanged(QString text);

	};

};

#endif

/*
Afghanistan			0093
Alaska				001
Albania				00355
Algeria				00213
Andorra				00376
Angola				00244
Anguilla			001 264
Antigua e Barbuda		001 268
Antille Olandesi		00599
Arabia Saudita			00966
Argentina			0054
Armenia				00374
Aruba				00297
Ascensione			00247
Australia			0061
Australia Antartic		0067210-1-2
Austria				0043
Azerbaigian			00994
Bahamas				001 242
Bahrein				00973
Bangladesh			00880
Barbados			001 246
Belgio				0032
Belize				00501
Benin				00229
Bermuda				001 441
Bhutan				00975
Bielorussia			00375
Bolivia				00591
Bosnia Erzegovina		00387
Botswana			00267
Brasile				0055
Brunei				00673
Bulgaria			00359
Burkina Faso			00226
Burundi				00257
Cambogia			00855
Camerun				00237
Canada				001
Capo Verde			00238
Ciad				00235
Cile				0056
Cina				0086
Cipro				00357
Colombia			0057
Comore				00269
Congo				00242
Cook				00682
Corea del Nord			00850
Corea del Sud			0082
Costa d'Avorio			00225
Costarica			00506
Croazia				00385
Cuba				0053
Danimarca			0045
Diego Garcia			00246
Dominica			001 767
Ecuador				00593
Egitto				0020
El Salvador			00503
Emirati Arabi Uniti		00971
Eritrea				00291
Estonia				00372
Etiopia				00251
Federazione Russa		007
Figi				00679
Filippine			0063
Finlandia			00358
Francia				0033
Gabon				00241
Gambia				00220
Georgia				00995
Germania			0049
Ghana				00233
Giamaica			001 876
Giappone			0081
Gibilterra			00350
Gibuti				00253
Giordania			00962
Gran Bretagna			0044
Grecia				0030
Grenada				001 473
Groenlandia			00299
Guadalupa			00590
Guam				00671
Guatemala			00502
Guinea				00224
Guinea Bissau			00245
Guinea Ecuatoriale		00240
Guyana				00592
Guyana Francese			00594
Haiti				00509
Honduras			00504
Hong Kong			00852
India				0091
Indonesia			0062
Iran				0098
Iraq				00964
Irlanda				00353
Islanda				00354
Isole Cayman			001 345
Isole Falkland			00500
Isole F�r Oer			00298
Isole Marianne			00670
Isole Marshall			00692
Isole Norfolk			00672
Isole Salomone			00677
Isole Vergini (GBR)		001 284
Isole Vergini (U.S.)		001 340
Israele				00972
Kazakistan			00996
Kenia				00254
Kirghizstan			00996
Kiribati			00686
Kuwait				00965
Laos				00856
Lesotho				00266
Lettonia			00371
Libano				00961
Liberia				00231
Libia				00218
Liechtenstein			00423
Lituania			00370
Lussemburgo			00352
Macao				00853
Macedonia			00389
Madagascar			00261
Malawi				00265
Maldive				00960
Malesia				0060
Mali				00223
Malta				00356
Marocco				00212
Martinica			00596
Mauritania			00222
Mauritius			00230
Messico				0052
Moldavia			00373
Monaco (Principato di)		00377
Mongolia			00976
Montserrat			001 664
Mozambico			00258
Namibia				00264
Nepal				00977
Nicaragua			00505
Nigeria				00234
Niue				00683
Norvegia			0047
Nuova Caledonia			00687
Nuova Zelanda			0064
Oman				00968
Paesi Bassi (Olanda)		0031
Pakistan			0092
Palau				00680
Panama				00507
Papua Nuova Guinea		00675
Paraguay			00595
Per�				0051
Polinesia Francese		00689
Polonia				0048
Portogallo			00351
Porto Rico			001 787
Qatar				00974
Rep. Ceca			00420
Rep. Centrafrica		00236
Rep. Democratica del Congo	00243
Rep. Dominicana			001
Reunion (Francia)		00262
Romania				0040
Ruanda				00250
Saint Elena			00290
Saint Kitts e Nevis		001 869
Saint Pierre e Miquelon		00508
Saint Vincent			001 784
Samoa Americane			00684
Samoa Occidentale		00685
Santa Lucia			001 758
Sao Tom� e Principe		00239
Senegal				00221
Seychelles			00248
Sierra Leone			00232
Singapore			0065
Siria				00963
Slovacchia			00421
Slovenia			00386
Somalia				00252
Spagna				0034
Sri Lanka			0094
Sudafrica			0027
Sudan				00249
Svezia				0046
Svizzera			0041
Swaziland			00268
Tajikistan			00737
Taiwan				00886
Tanzania			00255
Thailandia			0066
Togo				00228
Tonga				00676
Trinidad e Tobago		001 868
Tunisia				00216
Turchia				0090
Turkmenistan			00993
Turks e Caicos			001 649
Tuvalu				00688
Ucraina				00380
Uganda				00256
Ungheria			0036
Uruguay				00598
USA				001
Uzbekistan			00998
Vanuato				00678
Venezuela			0058
Vietnam				0084
Wallis e Futuna			00681
Yemen				00967
Yugoslavia			00381
Zambia				00260
Zimbabwe			00263
*/
