/*
 * main.cpp
 *
 * $author Pietro Spinella (pietro.spinella@gmail.com)
 * $license GPLv3
 */

#include <QApplication>
#include <QLocale>
#include <QTranslator>

#include "mainwindow.h"
#include "core/kms.h"

#include <iostream>

using namespace kms;
using namespace std;

int main(int argc, char *argv[])
{
	// Usage
	if(argc > 1 && argc < 4)
	{
		cout << "Usage: kms <xml_file> <service> <sequence> [<input_value> [<input_value> ... [<input_value>]]]" << endl;
		cout << "Example: kms kms.xml www.vodafone.it.mms loginSendLogout +393491234567 \"I want to say...\" \"Hello world!\"" << endl;
		return 0;
	}

	// Gui
	if(argc == 1)
	{
		// Create the application
		QApplication application(argc, argv);

		// Create and set the translator
		QTranslator translator;
		translator.load("./kms_" + QLocale::system().name());
		application.installTranslator(&translator);

		// Create and show the main window
		MainWindow mainWindow;
		mainWindow.setVisible(true);

		// Return the result of the application
		return application.exec();
	}

	// Command line
	if(argc >= 4)
	{
		// Create the application
		QApplication application(argc, argv);

		// Store some informations
		char *xmlFile = argv[1];
		char *serviceId = argv[2];
		char *sequenceId = argv[3];
		int argumentCount = argc - 4;

		// Create and set kms
		Kms kms;
		kms.load(xmlFile);

		// Check for errors
		int argumentCountExpected = kms.getUsedInputCount(serviceId, sequenceId, "constant") + kms.getUsedInputCount(serviceId, sequenceId, "variable");
		if(argumentCount != argumentCountExpected) {
			cout << "Note: \"kms " << serviceId << " " << sequenceId << "\" requires " << argumentCountExpected << " arguments instead of " << argumentCount << endl;
			cout << "Usage: kms " << serviceId << " " << sequenceId << " ";
			const QList<Input *> *inputList = kms.getInputList(serviceId);
			const QList<UsedInput *> *usedInputList = kms.getUsedInputList(serviceId, sequenceId);
			int inputListSize = inputList->size();
			int usedInputListSize = usedInputList->size();
			for(int i = 0; i < inputListSize; i++) {
				Input *input = inputList->at(i);
				for(int j = 0; j < usedInputListSize; j++) {
					UsedInput *usedInput = usedInputList->at(j);
					if(usedInput->getInput() == input->getId()) {
						if(input->getType() == "constant" || input->getType() == "variable") {
							cout << "<" << kms.evaluateText(serviceId, input->getName()).toStdString() << "> ";
						}
					}
				}
			}
			cout << endl;
		}

		// Set the inputs
		QList< QPair<QString, QString> > inputDataList;
		const QList<UsedInput *> *usedInputList = kms.getUsedInputList(serviceId, sequenceId);
		const QList<Input *> *inputList = kms.getInputList(serviceId);
		int usedInputListSize = usedInputList->size();
		int inputListSize = inputList->size();
		for(int i = 0; i < usedInputListSize && i < argumentCount; i++) {
			UsedInput *usedInput = usedInputList->at(i);
			for(int j = 0; j < inputListSize; j++) {
				Input *input = inputList->at(j);
				if(usedInput->getInput() == input->getId()) {
					if(input->getType() == "constant" || input->getType() == "variable") {
						QString id = input->getId();
						QString value = QString(argv[4 + i]);
						inputDataList.append(QPair<QString, QString>(id, value));
					}
				}
			}
		}

		// Perform the sequence
		kms.performSequence(serviceId, sequenceId, inputDataList);

		// Return the result of the application
		return application.exec();
	}
}
