/*
 * compactalgorithm.cpp
 *
 * $author Pietro Spinella (pietro.spinella@gmail.com)
 * $license GPLv3
 */

#include "compactalgorithm.h"

using namespace kms;

kms::CompactAlgorithm::CompactAlgorithm()
{
	// Create and set the SimpleAlgorithm that uses the default dictionary and ElegantAlgorithm
	_simpleAlgorithm = new SimpleAlgorithm;
	_elegantAlgorithm = new ElegantAlgorithm;
}

kms::CompactAlgorithm::CompactAlgorithm(QList< QPair<QString, QString> > *dictionary)
{
	// Create and set the SimpleAlgorithm that uses the given dictionary and ElegantAlgorithm
	_simpleAlgorithm = new SimpleAlgorithm(dictionary);
	_elegantAlgorithm = new ElegantAlgorithm;
}

kms::CompactAlgorithm::~CompactAlgorithm()
{
	// Deletes the SimpleAlgorithm and ElegantAlgorithm
	delete _simpleAlgorithm;
	delete _elegantAlgorithm;
}

void kms::CompactAlgorithm::setDictionary(QList< QPair<QString, QString> > *dictionary)
{
	_simpleAlgorithm->setDictionary(dictionary);
}

QString kms::CompactAlgorithm::pack(const QString &text) const
{
	return _elegantAlgorithm->pack(_simpleAlgorithm->pack(text));
}
