/*
 * compactalgorithm.h
 *
 * $author Pietro Spinella (pietro.spinella@gmail.com)
 * $license GPLv3
 */

#ifndef KMS_COMPACTALGORITHM_H
#define KMS_COMPACTALGORITHM_H

#include <QList>
#include <QPair>
#include <QString>

#include "packingalgorithm.h"
#include "simplealgorithm.h"
#include "elegantalgorithm.h"

namespace kms
{
	class CompactAlgorithm : public PackingAlgorithm
	{
		public:
			// Constructs a CompactAlgorithm.
			CompactAlgorithm();
			// Constructs a CompactAlgorithm that uses the given dictionary. The CompactAlgorithm doesn't take the ownership of the given dictionary.
			CompactAlgorithm(QList< QPair<QString, QString> > *dictionary);
			// Destroys the CompactAlgorithm.
			~CompactAlgorithm();

			// Sets the default dictionary to the CompactAlgorithm. The CompactAlgorithm doesn't take the ownership of the given dictionary.
			void setDictionary(QList< QPair<QString, QString> > *dictionary);

			// Implements the abstract pack method of packingalgorithm.h.
			QString pack(const QString &text) const;

		private:
			// Stores the SimpleAlgorithm and ElegantAlgorithm.
			SimpleAlgorithm *_simpleAlgorithm;
			ElegantAlgorithm *_elegantAlgorithm;
	};
};

#endif
