/*
 * crypticalgorithm.cpp
 *
 * $author Pietro Spinella (pietro.spinella@gmail.com)
 * $license GPLv3
 */

#include "crypticalgorithm.h"

using namespace kms;

kms::CrypticAlgorithm::CrypticAlgorithm()
{
	// Create and set the SimpleAlgorithm that uses the default dictionary and SmartAlgorithm
	_simpleAlgorithm = new SimpleAlgorithm;
	_smartAlgorithm = new SmartAlgorithm;
}

kms::CrypticAlgorithm::CrypticAlgorithm(QList< QPair<QString, QString> > *dictionary)
{
	// Create and set the SimpleAlgorithm that uses the given dictionary and SmartAlgorithm
	_simpleAlgorithm = new SimpleAlgorithm(dictionary);
	_smartAlgorithm = new SmartAlgorithm;
}

kms::CrypticAlgorithm::~CrypticAlgorithm()
{
	// Deletes the SimpleAlgorithm and SmartAlgorithm
	delete _simpleAlgorithm;
	delete _smartAlgorithm;
}

void kms::CrypticAlgorithm::setDictionary(QList< QPair<QString, QString> > *dictionary)
{
	_simpleAlgorithm->setDictionary(dictionary);
}

QString kms::CrypticAlgorithm::pack(const QString &text) const
{
	return _smartAlgorithm->pack(_simpleAlgorithm->pack(text));
}
