/*
 * crypticalgorithm.h
 *
 * $author Pietro Spinella (pietro.spinella@gmail.com)
 * $license GPLv3
 */

#ifndef KMS_CRYPTICALGORITHM_H
#define KMS_CRYPTICALGORITHM_H

#include <QList>
#include <QPair>
#include <QString>

#include "packingalgorithm.h"
#include "simplealgorithm.h"
#include "smartalgorithm.h"

namespace kms
{
	class CrypticAlgorithm : public PackingAlgorithm
	{
		public:
			// Constructs a CrypticAlgorithm.
			CrypticAlgorithm();
			// Constructs a CrypticAlgorithm that uses the given dictionary. The CrypticAlgorithm doesn't take the ownership of the given dictionary.
			CrypticAlgorithm(QList< QPair<QString, QString> > *dictionary);
			// Destroys the CrypticAlgorithm.
			~CrypticAlgorithm();

			// Sets the default dictionary to the CrypticAlgorithm. The CrypticAlgorithm doesn't take the ownership of the given dictionary.
			void setDictionary(QList< QPair<QString, QString> > *dictionary);

			// Implements the abstract pack method of packingalgorithm.h.
			QString pack(const QString &text) const;

		private:
			// Stores the SimpleAlgorithm and SmartAlgorithm.
			SimpleAlgorithm *_simpleAlgorithm;
			SmartAlgorithm *_smartAlgorithm;
	};
};

#endif
