/*
 * nastyalgorithm.cpp
 *
 * $author Pietro Spinella (pietro.spinella@gmail.com)
 * $license GPLv3
 */

#include "nastyalgorithm.h"

using namespace kms;

kms::NastyAlgorithm::NastyAlgorithm()
{
	// Create and set the SimpleAlgorithm that uses the default dictionary, SmartAlgorithm and ElegantAlgorithm
	_simpleAlgorithm = new SimpleAlgorithm;
	_smartAlgorithm = new SmartAlgorithm;
	_elegantAlgorithm = new ElegantAlgorithm;
}

kms::NastyAlgorithm::NastyAlgorithm(QList< QPair<QString, QString> > *dictionary)
{
	// Create and set the SimpleAlgorithm that uses the given dictionary, SmartAlgorithm and ElegantAlgorithm
	_simpleAlgorithm = new SimpleAlgorithm(dictionary);
	_smartAlgorithm = new SmartAlgorithm;
	_elegantAlgorithm = new ElegantAlgorithm;
}

kms::NastyAlgorithm::~NastyAlgorithm()
{
	// Deletes the SimpleAlgorithm, SmartAlgorithm and ElegantAlgorithm
	delete _simpleAlgorithm;
	delete _smartAlgorithm;
	delete _elegantAlgorithm;
}

void kms::NastyAlgorithm::setDictionary(QList<QPair<QString, QString> > *dictionary)
{
	_simpleAlgorithm->setDictionary(dictionary);
}

QString kms::NastyAlgorithm::pack(const QString &text) const
{
	return _elegantAlgorithm->pack(_smartAlgorithm->pack(_simpleAlgorithm->pack(text)));
}
