/*
 * nastyalgorithm.h
 *
 * $author Pietro Spinella (pietro.spinella@gmail.com)
 * $license GPLv3
 */

#ifndef KMS_NASTYALGORITHM_H
#define KMS_NASTYALGORITHM_H

#include <QList>
#include <QPair>
#include <QString>

#include "packingalgorithm.h"
#include "simplealgorithm.h"
#include "smartalgorithm.h"
#include "elegantalgorithm.h"

namespace kms
{
	class NastyAlgorithm : public PackingAlgorithm
	{
		public:
			// Constructs a NastyAlgorithm.
			NastyAlgorithm();
			// Constructs a NastyAlgorithm that uses the given dictionary. The NastyAlgorithm doesn't take the ownership of the given dictionary.
			NastyAlgorithm(QList< QPair<QString, QString> > *dictionary);
			// Destroys the NastyAlgorithm.
			~NastyAlgorithm();

			// Sets the default dictionary to the NastyAlgorithm. The NastyAlgorithm doesn't take the ownership of the given dictionary.
			void setDictionary(QList< QPair<QString, QString> > *dictionary);

			// Implements the abstract pack method of packingalgorithm.h.
			QString pack(const QString &text) const;

		private:
			// Stores the SimpleAlgorithm, SmartAlgorithm and ElegantAlgorithm.
			SimpleAlgorithm *_simpleAlgorithm;
			SmartAlgorithm *_smartAlgorithm;
			ElegantAlgorithm *_elegantAlgorithm;
	};
};

#endif
