/*
 * simplealgorithm.h
 *
 * $author Pietro Spinella (pietro.spinella@gmail.com)
 * $license GPLv3
 */

#ifndef KMS_SIMPLEALGORITHM_H
#define KMS_SIMPLEALGORITHM_H

#include <QList>
#include <QPair>
#include <QString>

#include "packingalgorithm.h"

namespace kms
{
	class SimpleAlgorithm : public PackingAlgorithm
	{
		public:
			// Constructs a SimpleAlgorithm.
			SimpleAlgorithm();
			// Constructs a SimpleAlgorithm that uses the given dictionary. The SimpleAlgorithm doesn't take the ownership of the given dictionary.
			SimpleAlgorithm(QList< QPair<QString, QString> > *dictionary);
			// Destroys the SimpleAlgorithm.
			~SimpleAlgorithm();

			// Sets the default dictionary to the SimpleAlgorithm. The SimpleAlgorithm doesn't take the ownership of the given dictionary.
			void setDictionary(QList< QPair<QString, QString> > *dictionary);

			// Implements the abstract pack method of packingalgorithm.h.
			QString pack(const QString &text) const;

		private:
			// Stores the default dictionary.
			QList< QPair<QString, QString> > *_dictionary;
	};
};

#endif
