/*
 * textpacker.cpp
 *
 * $author Pietro Spinella (pietro.spinella@gmail.com)
 * $license GPLv3
 */

#include "textpacker.h"
#include "simplealgorithm.h"

using namespace kms;

kms::TextPacker::TextPacker()
{
	// Create and set the default PackingAlgorithm
	_algorithm = new SimpleAlgorithm;
}

kms::TextPacker::TextPacker(PackingAlgorithm *packingAlgorithm) : _algorithm(packingAlgorithm)
{
	// Do nothing...
}

kms::TextPacker::~TextPacker()
{
	if(_algorithm != 0)
	{
		delete _algorithm;
	}
}

void kms::TextPacker::giveDefaultPackingAlgorithm(PackingAlgorithm *algorithm)
{
	if(_algorithm != 0)
	{
		delete _algorithm;
	}
	_algorithm = algorithm;
}

QString kms::TextPacker::pack(const QString &text) const
{
	return _algorithm != 0 ? _algorithm->pack(text) : text;
}

QString kms::TextPacker::pack(const QString &text, PackingAlgorithm *algorithm) const
{
	return algorithm != 0 ? algorithm->pack(text) : text;
}
