/*
 * textpacker.h
 *
 * $author Pietro Spinella (pietro.spinella@gmail.com)
 * $license GPLv3
 */

#ifndef KMS_TEXTPACKER_H
#define KMS_TEXTPACKER_H

#include <QString>

#include "packingalgorithm.h"

namespace kms
{
	class TextPacker
	{
		public:
			// Constructs a TextPacker that uses the default PackingAlgorithm.
			TextPacker();
			// Constructs a TextPacker that uses the given PackingAlgorithm. The TextPacker takes the ownership of the given PackingAlgorithm.
			TextPacker(PackingAlgorithm *algorithm);
			// Destroys the TextPacker.
			~TextPacker();

			// Gives the default PackingAlgorithm to the TextPacker. The TextPacker takes the ownership of the given PackingAlgorithm.
			void giveDefaultPackingAlgorithm(PackingAlgorithm *algorithm);

			// Packs the given text using the default PackingAlgorithm.
			QString pack(const QString &text) const;
			// Packs the given text using the given PackingAlgorithm. The TextPacker doesn't take the ownership of the given PackingAlgorithm.
			QString pack(const QString &text, PackingAlgorithm *algorithm) const;

		private:
			// Stores the default PackingAlgorithm.
			PackingAlgorithm *_algorithm;
	};
};

#endif
